==> calligra_2.8.5.orig.tar.xz: calligra-2.8.5/krita/plugins/paintops/libpaintop/kis_pressure_spacing_option.cpp <==
/* This file is part of the KDE project
 * Copyright (c) 2011 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "kis_pressure_spacing_option.h"

#include <klocale.h>

const QString ISOTROPIC_SPACING = "Spacing/Isotropic";

KisPressureSpacingOption::KisPressureSpacingOption()
    : KisCurveOption(i18n("Spacing"), "Spacing", KisPaintOpOption::brushCategory(), false),
      m_isotropicSpacing(false)
{
    setMinimumLabel(i18n("0%"));
    setMaximumLabel(i18n("100%"));
}


double KisPressureSpacingOption::apply(const KisPaintInformation & info) const
{
    if (!isChecked())
        return 1.0;

    return computeValue(info);
}

void KisPressureSpacingOption::setIsotropicSpacing(bool isotropic)
{
    m_isotropicSpacing = isotropic;
}

bool KisPressureSpacingOption::isotropicSpacing() const
{
    return m_isotropicSpacing;
}

void KisPressureSpacingOption::writeOptionSetting(KisPropertiesConfiguration* setting) const
{
    KisCurveOption::writeOptionSetting(setting);
    setting->setProperty(ISOTROPIC_SPACING, m_isotropicSpacing);
}

void KisPressureSpacingOption::readOptionSetting(const KisPropertiesConfiguration* setting)
{
    KisCurveOption::readOptionSetting(setting);
    m_isotropicSpacing = setting->getBool(ISOTROPIC_SPACING, false);
}

==> calligra-2.9.4.tar.xz: calligra-2.9.4/krita/plugins/paintops/libpaintop/kis_pressure_spacing_option.cpp <==
/* This file is part of the KDE project
 * Copyright (c) 2011 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "kis_pressure_spacing_option.h"

#include <klocale.h>

const QString ISOTROPIC_SPACING = "Spacing/Isotropic";

KisPressureSpacingOption::KisPressureSpacingOption()
    : KisCurveOption(i18n("Spacing"), "Spacing", KisPaintOpOption::generalCategory(), false),
      m_isotropicSpacing(false)
{
    setMinimumLabel(i18n("0%"));
    setMaximumLabel(i18n("100%"));
}


double KisPressureSpacingOption::apply(const KisPaintInformation & info) const
{
    if (!isChecked())
        return 1.0;

    return computeValue(info);
}

void KisPressureSpacingOption::setIsotropicSpacing(bool isotropic)
{
    m_isotropicSpacing = isotropic;
}

bool KisPressureSpacingOption::isotropicSpacing() const
{
    return m_isotropicSpacing;
}

void KisPressureSpacingOption::writeOptionSetting(KisPropertiesConfiguration* setting) const
{
    KisCurveOption::writeOptionSetting(setting);
    setting->setProperty(ISOTROPIC_SPACING, m_isotropicSpacing);
}

void KisPressureSpacingOption::readOptionSetting(const KisPropertiesConfiguration* setting)
{
    KisCurveOption::readOptionSetting(setting);
    m_isotropicSpacing = setting->getBool(ISOTROPIC_SPACING, false);
}
